==> firexcode-0.7.2.tar.gz: example/lib/example/BlogTile.dart <==
import 'package:firexcode/firexcode.dart';

class ExampleBlogTile extends StatefulWidget {
  @override
  _ExampleBlogTileState createState() => _ExampleBlogTileState();
}

class _ExampleBlogTileState extends State<ExampleBlogTile> {
  @override
  Widget build(BuildContext context) {
    return <Widget>[
      XBlogTile(
        tileOnTap: () {},
        backSideBackgroundColor: Colors.grey[100],
        cardElevation: 5,
        imageHeight: 200,
        onTap: () {},
        backrounded: 10,
        shape: BorderRadius.circular(10).xShapeBorder(),
        leading: "Z"
            .textMaterialColorWhite()
            .xCircleAvatar(backgroundColor: Colors.black, radius: 25),
        title: "Image Editor Pro".textMaterialColorBlack(),
        subTitle: "Goto PubDev Check".textMaterial(),
        trailing: '10 min ago'.textMaterial(),
        image:
            "https://user-images.githubusercontent.com/55942632/77652902-fedd9980-6f94-11ea-96d5-d31657590893.png"
                .decorationINToCover(),
      ),
      XBlogTile(
        rounded: 10,
        color: Color(0xFFff1632),
        tileOnTap: () {},
        backSideBackgroundColor: Colors.grey[100],
        cardElevation: 5,
        imageHeight: 200,
        onTap: () {},
        backrounded: 10,
        shape: BorderRadius.circular(10).xShapeBorder(),
        leading: "Z"
            .textMaterialColorWhite()
            .xCircleAvatar(backgroundColor: Colors.white, radius: 25),
        title: "Image Editor Pro".textMaterialColorWhite(),
        subTitle: "Goto PubDev Check".textMaterial(color: Colors.grey[50]),
        trailing: '10 min ago'.textMaterial(
          color: Colors.white,
        ),
        image:
            "https://user-images.githubusercontent.com/45489310/78457255-b9d4f980-765d-11ea-8d17-78bb21297de6.png"
                .decorationINToCover(),
      ),
      XBlogTile(
        color: Colors.orange,
        tileOnTap: () {},
        backSideBackgroundColor: Colors.grey[100],
        cardElevation: 5,
        imageHeight: 200,
        onTap: () {},
        backrounded: 10,
        shape: BorderRadius.circular(10).xShapeBorder(),
        leading: "Z"
            .textMaterial(fontWeight: FontWeight.bold, color: Colors.black)
            .xCircleAvatar(backgroundColor: Colors.white, radius: 25),
        title: "Image Editor Pro".textMaterialColorWhite(),
        subTitle: "Goto PubDev Check".textMaterial(color: Colors.grey[50]),
        trailing: '10 min ago'.textMaterial(
          color: Colors.white,
        ),
        image:
            "https://user-images.githubusercontent.com/55942632/77652902-fedd9980-6f94-11ea-96d5-d31657590893.png"
                .decorationINToCover(),
      ),
    ].xListView().xap(value: 10.0).xScaffold(
          backgroundColor: Colors.white,
          appBar: new AppBar(
            brightness: Brightness.light,
            centerTitle: true,
            backgroundColor: Colors.white,
            title: "BlogTile ".textMaterialColorBlack(),
          ),
        );
  }
}

==> firexcode-0.7.4.tar.gz: example/lib/example/BlogTile.dart <==
import 'package:firexcode/firexcode.dart';

class ExampleBlogTile extends StatefulWidget {
  @override
  _ExampleBlogTileState createState() => _ExampleBlogTileState();
}

class _ExampleBlogTileState extends State<ExampleBlogTile> {
  @override
  Widget build(BuildContext context) {
    return <Widget>[
      XBlogTile(
        tileOnTap: () {},
        backSideBackgroundColor: Colors.grey[100],
        cardElevation: 5,
        imageHeight: 200,
        onTap: () {},
        backrounded: 10,
        shape: BorderRadius.circular(10).xShapeBorder(),
        leading: 'Z'
            .textMaterialColorWhite()
            .xCircleAvatar(backgroundColor: Colors.black, radius: 25),
        title: 'Image Editor Pro'.textMaterialColorBlack(),
        subTitle: 'Goto PubDev Check'.textMaterial(),
        trailing: '10 min ago'.textMaterial(),
        image:
            'https://user-images.githubusercontent.com/55942632/77652902-fedd9980-6f94-11ea-96d5-d31657590893.png'
                .decorationINToCover(),
      ),
      XBlogTile(
        rounded: 10,
        color: Color(0xFFff1632),
        tileOnTap: () {},
        backSideBackgroundColor: Colors.grey[100],
        cardElevation: 5,
        imageHeight: 200,
        onTap: () {},
        backrounded: 10,
        shape: BorderRadius.circular(10).xShapeBorder(),
        leading: 'Z'
            .textMaterialColorWhite()
            .xCircleAvatar(backgroundColor: Colors.white, radius: 25),
        title: 'Image Editor Pro'.textMaterialColorWhite(),
        subTitle: 'Goto PubDev Check'.textMaterial(color: Colors.grey[50]),
        trailing: '10 min ago'.textMaterial(
          color: Colors.white,
        ),
        image:
            'https://user-images.githubusercontent.com/45489310/78457255-b9d4f980-765d-11ea-8d17-78bb21297de6.png'
                .decorationINToCover(),
      ),
      XBlogTile(
        color: Colors.orange,
        tileOnTap: () {},
        backSideBackgroundColor: Colors.grey[100],
        cardElevation: 5,
        imageHeight: 200,
        onTap: () {},
        backrounded: 10,
        shape: BorderRadius.circular(10).xShapeBorder(),
        leading: 'Z'
            .textMaterial(fontWeight: FontWeight.bold, color: Colors.black)
            .xCircleAvatar(backgroundColor: Colors.white, radius: 25),
        title: 'Image Editor Pro'.textMaterialColorWhite(),
        subTitle: 'Goto PubDev Check'.textMaterial(color: Colors.grey[50]),
        trailing: '10 min ago'.textMaterial(
          color: Colors.white,
        ),
        image:
            'https://user-images.githubusercontent.com/55942632/77652902-fedd9980-6f94-11ea-96d5-d31657590893.png'
                .decorationINToCover(),
      ),
    ].xListView().xap(value: 10.0).xScaffold(
          backgroundColor: Colors.white,
          appBar: AppBar(
            brightness: Brightness.light,
            centerTitle: true,
            backgroundColor: Colors.white,
            title: 'BlogTile '.textMaterialColorBlack(),
          ),
        );
  }
}
